/***학력 및 교육년수 변수를 구성하는 방법***/
 
clear
cd "D:\klips\Stata"

use klips22p, replace 

/**학력 더미변수 만들기 (edu)**/ 

// (참고) 개인용 자료에 있는 학력 자료는 가구용 자료에서 가져오는 자료임

// p**0110 : 학력(학교)
// h**0661-h**0675: 학력(학교)
// p**0111: 학력(이수여부)
// h**0681-h**0695: 학력(이수여부)


recode p220110(1/4=1)(5=2)(6=3)(7=4)(8/9=5), gen(edu) // 1)미취학,2)무학,3)초등학교,4)중학교,5)고등학교,6)2년제대학,전문대학,7)4년제대학,8)대학원석사,9)대학원박사 
mvdecode edu, mv(-1) // -1값을 결측치로 전환

recode p220111(1=1)(2/5=2), gen(degree) //1)졸업,2)수료,3)중퇴,4)재학중,5)휴학중
mvdecode degree, mv(-1) // -1값을 결측치로 전환
replace edu =1 if edu==2 & degree!=1 // 졸업을 제외한 나머지는 하위학력코딩
replace edu =2 if edu==3 & degree!=1 // "~"를 사용해도 됨
replace edu =3 if edu==4 & degree!=1
replace edu =4 if edu==5 & degree!=1

tab edu, gen(edu_dum_) // 한 변수를 가지고 다수의 더미변수를 만드는 명령문

lab var edu "학력:1)고졸,2)전문대졸,3)대졸,4)석사이상" 
lab var degree "이수여부:1)졸업,2)수료,중퇴,재학중,휴학중" 	

tab edu
tab degree


/**교육년수 변수 (edu_scale)**/	
	
// (참고) 졸업인 경우(p**0111=1), 학년(p**0112)은 . 처리 되어 있음 

// p**0112: 학력(학년)	
	
gen level = p220112 	
recode p220110(1/2=0)(3=6)(4=9)(5=12)(6=14)(7=16)(8=18)(9=21), gen(edu_scale)

// 초등학교
replace edu_scale=1 if p220110==3 & p220112==1 
replace edu_scale=2 if p220110==3 & p220112==2
replace edu_scale=3 if p220110==3 & p220112==3
replace edu_scale=4 if p220110==3 & p220112==4
replace edu_scale=5 if p220110==3 & p220112==5
replace edu_scale=6 if p220110==3 & p220112==6

// 중학교
replace edu_scale=7 if p220110==4 & p220112==1
replace edu_scale=8 if p220110==4 & p220112==2
replace edu_scale=9 if p220110==4 & p220112==3

// 고등학교
replace edu_scale=10 if p220110==5 & p220112==1
replace edu_scale=11 if p220110==5 & p220112==2
replace edu_scale=12 if p220110==5 & p220112==3

// 2년제대학,전문대학
replace edu_scale=13 if p220110==6 & p220112==1
replace edu_scale=14 if p220110==6 & p220112==2

// 4년제대학
replace edu_scale=13 if p220110==7 & p220112==1
replace edu_scale=14 if p220110==7 & p220112==2
replace edu_scale=15 if p220110==7 & p220112==3
replace edu_scale=16 if p220110==7 & p220112==4

// 대학원석사
replace edu_scale=17 if p220110==8 & p220112==1
replace edu_scale=18 if p220110==8 & p220112==2

// 대학원박사
replace edu_scale=19 if p220110==9 & p220112==1
replace edu_scale=20 if p220110==9 & p220112==2
replace edu_scale=21 if p220110==9 & p220112==3

mvdecode edu_scale, mv(-1) // 결측치 처리 

lab var edu_scale "교육년수"
tab edu_scale 

// (참고) 대학/대학원의 정규 교육년수가 넘어서는 경우, 비이상적인 학년(예: 초등학교 7학년) 등은 edu_scale변수의 교육년수 계산에 있어 반영하지 않음

count if p220110==3 & (p220112 >=7 & p220112 !=.) // stata에서 .는 결측값(.)을 무한대 처리함. 
count if p220110==4 & (p220112 >=4 & p220112 !=.) 
count if p220110==5 & (p220112 >=4 & p220112 !=.) 
count if p220110==6 & (p220112 >=3 & p220112 !=.)
count if p220110==7 & (p220112 >=4 & p220112 !=.)
count if p220110==8 & (p220112 >=3 & p220112 !=.)
count if p220110==9 & (p220112 >=4 & p220112 !=.) 

save "D:\klips\Stata\data\exaple.dta", replace 